@@ -79,10 +79,14 @@ git_remote <- function(url, subdir = NULL, ref = NULL, credentials = git_credent
     stop("`credentials` can only be used with `git = \"git2r\"`", call. = FALSE)
   }
 
-  meta <- re_match(url, "(?<url>(?:git@)?[^@]*)(?:@(?<ref>.*))?")
-  ref <- ref %||% (if (meta$ref == "") NULL else meta$ref)
+   url_parts = re_match( url,
+         "(?<protocol>[^/]*://)?(?<authhost>[^/]+)(?<path>[^@]*)(@(?<ref>.*))?")
 
-  list(git2r = git_remote_git2r, external = git_remote_xgit)[[git]](meta$url, subdir, ref, credentials)
+  ref <- ref %||% (if (url_parts$ref == "") NULL else url_parts$ref)
+
+  url = paste0(url_parts$protocol, url_parts$authhost, url_parts$path)
+
+  list(git2r = git_remote_git2r, external = git_remote_xgit)[[git]](url, subdir, ref, credentials)
 }
 
 
